Simulate empirical distribution of sample size and number of effect sizes
Source:R/data-generation.R
n_ES_empirical.RdA functional that takes in a dataset with empirical distribution of primary study sample sizes and number of effect sizes per primary study and returns a function that generates random samples from the dataset